import type { EthersFetcherConfig } from "./fetchers/ethers/types";
import type { EthereumFetcherConfig } from "./fetchers/ethereum/types";
export declare type Address = string;
export declare type NftResultLoading = {
    status: "loading";
    loading: true;
    error: undefined;
    nft: undefined;
    reload: () => Promise<boolean>;
};
export declare type NftResultError = {
    status: "error";
    loading: false;
    error: Error;
    nft: undefined;
    reload: () => Promise<boolean>;
};
export declare type NftResultDone = {
    status: "done";
    loading: false;
    error: undefined;
    nft: NftMetadata;
    reload: () => Promise<boolean>;
};
export declare type NftResult = NftResultLoading | NftResultError | NftResultDone;
export declare type NftMetadata = {
    description: string;
    image: string;
    name: string;
    owner: Address;
};
export declare type NftJsonMetadata = {
    description: string;
    image: string;
    name: string;
};
export declare type ContractMethod = {
    address: string;
    methodName: string;
    methodHash: string;
    humanReadableAbi: [string];
};
export declare type Fetcher<Config> = {
    config: Config;
    fetchNft: (contractAddress: Address, tokenId: string) => Promise<NftMetadata>;
};
export declare type FetcherDeclarationEthers = [
    name: "ethers",
    config: EthersFetcherConfig
];
export declare type FetcherDeclarationEthereum = [
    name: "ethereum",
    config: EthereumFetcherConfig
];
export declare type FetcherDeclaration = FetcherDeclarationEthers | FetcherDeclarationEthereum;
export declare type FetcherProp = Fetcher<unknown> | FetcherDeclaration | null | undefined;
